@@ -3,6 +3,7 @@
 import re
 import string
 
+from ddf import G
 from django.test import Client, TestCase
 from django.urls import get_resolver, reverse
 from django_extensions.management.commands import show_urls
@@ -14,6 +15,15 @@ def get_real_url(view, urlname, urlpattern):
     arguments = re.findall("<[^>]*>", urlpattern)
     if not arguments:
         return reverse(urlname)
+    if hasattr(view, "view_class"):
+        # TODO: Hopthesis create form: view.view_class.form_class
+        if hasattr(view.view_class, "model"):
+            # likely an ID which is required url argument
+            if len(arguments) == 1:
+                model = view.view_initkwargs.get("model") or view.view_class.model
+                urlargname = arguments[0].strip("<>").split(":")[-1]
+                obj = G(model)
+                return reverse(urlname, kwargs={urlargname: obj.id})
     return None
 
 
@@ -31,6 +41,9 @@ class TestAllURLs(TestCase):
             urlpattern,
             urlname,
         ) in allurls:
+            if urlname is None:
+                print(f"URL with pattern {urlpattern} has no name")
+                continue
             url = get_real_url(view, urlname, urlpattern)
             if url is None:
                 print(f"URL {urlname} with pattern {urlpattern} cannot be tested")
