@@ -86,7 +86,8 @@ class CustomFormMixin:
                     mark_safe(
                         "<br/>".join(
                             [
-                                f"<em>{form.fields[field].label}</em>: {', '.join(msg if isinstance(msg, list) else [msg])}"
+                                f"<em>{form.fields[field].label}</em>: "
+                                f"{', '.join(msg if isinstance(msg, list) else [msg])}"
                                 for field, msg in form.errors.items()
                                 if field != "__all__"
                             ]
